##  Accessing Past Uploads and Analysis
To access past uploads and analyses, choose Inventory Builder - Import Overview in the right-side pane of the inventory. From the import overview, you can open the corresponding inbox for any item to continue reviewing and creating fact sheets and relations.
The status of each file helps you track its progress in the inventory builder workflow:
  * Uploaded: File uploaded, but no further action was taken.
  * Analyzed: File analyzed, but discovered items not yet added to the inbox.
  * Ready for review: Discovered items added to the inbox but not yet reviewed.
  * Reviewed: All discovered fact sheets and relations have been reviewed. They were either added to the inventory or rejected.
  * Error: Something went wrong while linking the discovery item to fact sheets or creating its relations. Try to link or create the affected item again.
